﻿using System.Collections.ObjectModel;
using System.Windows;
using Telerik.Windows.Controls.Map;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.DragDrop;
using System.Windows.Controls;
using System.Threading;
using System.Globalization;
using System.ComponentModel;
using System.Windows.Input;

namespace WpfDragDropPins
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		public ObservableCollection<Address> Addresses = new ObservableCollection<Address>();

		public MainWindow()
		{
			Thread.CurrentThread.CurrentCulture = new CultureInfo("en-US");

			InitializeComponent();

			this.Addresses.Add(new Address("Address line 1"));
			this.Addresses.Add(new Address("Address line 2"));
			this.Addresses.Add(new Address("Address line 3"));
			this.Addresses.Add(new Address("Address line 4"));

			this.gridView.ItemsSource = this.Addresses;
		}

		private void gridView_DragQuery(object sender, Telerik.Windows.Controls.DragDrop.DragDropQueryEventArgs e)
		{
			e.QueryResult = true;
		}

		private void radMap_DropQuery(object sender, Telerik.Windows.Controls.DragDrop.DragDropQueryEventArgs e)
		{
			RadGridView grid = e.Options.Source as RadGridView;
			if (grid != null && grid.SelectedItem != null)
			{
				e.Handled = true;
				e.QueryResult = true;
			}
		}

		private void radMap_DropInfo(object sender, Telerik.Windows.Controls.DragDrop.DragDropEventArgs e)
		{
			if (e.Options.Status == DragStatus.DropComplete)
			{
				RadGridView grid = e.Options.Source as RadGridView;
				if (grid != null && grid.SelectedItem != null)
				{
					e.Handled = true;

					Location location = Location.GetCoordinates(this.radMap, e.Options.RelativeDragPoint);

					Address address = grid.SelectedItem as Address;
					address.Location = location;

					Pushpin pin = new Pushpin();
					MapLayer.SetLocation(pin, location);

					this.informationLayer.Items.Add(pin);
				}
			}
			else
			{
				radMap.Cursor = Cursors.Pen;
			}

			if (e.Options.Status == DragStatus.DropComplete
				|| e.Options.Status == DragStatus.DropCancel)
			{
				radMap.Cursor = Cursors.Arrow;
			}
		}
	}

	public class Address : INotifyPropertyChanged
	{
		private Location location;
		public Location Location
		{
			get
			{
				return this.location;
			}
			set
			{
				this.location = value;
				NotifyPropertyChanged("Location");
			}
		}

		public string AddressLine
		{
			get;
			set;
		}

		public Address(string address)
		{
			this.AddressLine = address;
		}

		public event PropertyChangedEventHandler PropertyChanged;
		private void NotifyPropertyChanged(string propName)
		{
			PropertyChangedEventHandler handler = PropertyChanged;
			if (handler != null)
			{
				handler(this, new PropertyChangedEventArgs(propName));
			}
		}
	}
}
